<?php

    /*****
     *
     * Plugin name:     Recently Updated Pages
     * Description:     Purpose of this plugin is to display the list of pages (and optionally posts) on
     *                  Wordpress blog those have been recently updated.
     * Version:         1.0.1
     * Plugin URI:      http://resource.bdwebwork.com/WordpressPlugins/RecentlyUpdatedPages/
     * Author:          Ehsanul Haque
     * Author URI:      http://ehsan.bdwebwork.com/
     *
     */
    
    // Registering the widget
    function recently_updated_pages() {
        register_widget('Recently_Updated_Pages');
    }
    
    // Class Recently Updated Pages is extending WP_Widget class
    class Recently_Updated_Pages extends WP_Widget {
        function Recently_Updated_Pages() {
            $widgetSettings     = array (
                                        'classname'     => 'Recently_Updated_Pages',
                                        'description'   => 'Purpose of this plugin is to display the list of pages on Wordpress blog those have been recently updated.'
                                        );
            
            $controlSettings    = array (
                                        'width'         => 300,
                                        'height'        => 400,
                                        'id_base'       => 'recently_updated_pages'
                                        );
                                        
            $this->WP_Widget('recently_updated_pages', 'Recently Updated Pages', $widgetSettings, $controlSettings);
        }

        // Displaying the widget on the blog
        function widget($args, $instance) {
            extract($args);

            $title              = apply_filters('widget_title', $instance['title']);
            $totalPagesToShow   = (int) $instance['totalPagesToShow'];
            $showListWithPosts  = (int) $instance['showListWithPosts'];

            $defaults           = array (
                                        'title'             => 'Recently Updated Pages',
                                        'totalPagesToShow'  => 3,
                                        'showListWithPosts' => 0
                                        );
                                    
            echo $before_widget;

            if ($title != "") {
                echo $before_title . $title . $after_title;
            } else {
                echo $before_title . $defaults['title'] . $after_title;
            }

            if ($totalPagesToShow != 0) {
                $pageList       = $this->getListOfPages($totalPagesToShow, $showListWithPosts);
            } else {
                $pageList       = $this->getListOfPages($defaults['totalPagesToShow'], $defaults['showListWithPosts']);
            }

            if (!empty($pageList)) {
                echo "<ul>";
                    foreach ($pageList as $obj) {
                        echo "<li class='page_item page-item-{$obj->ID}'><a href='{$obj->uri}' title='{$obj->post_title}'>{$obj->post_title}</a> on {$obj->post_modified}</li>";
                    }
                echo "</ul>";
            }
            echo $after_widget;
        }        

        // Updating the settings
        function update($new_instance, $old_instance) {
            $instance                       = $old_instance;
            $instance['title']              = strip_tags($new_instance['title']);
            $instance['totalPagesToShow']   = strip_tags($new_instance['totalPagesToShow']);
            $instance['showListWithPosts']  = strip_tags($new_instance['showListWithPosts']);

            return $instance;
        }

        // WP Admin panel form to modify the setting
        function form($instance) {

            $defaults       = array ( 
                                    'title'             => 'Recently Updated Pages', 
                                    'totalPagesToShow'  => 3,
                                    'showListWithPosts' => 0
                                    );
                                    
            $instance       = wp_parse_args((array) $instance, $defaults);
?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
			<input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('totalPagesToShow'); ?>">Total Pages to Show:</label>
			<input id="<?php echo $this->get_field_id('totalPagesToShow'); ?>" name="<?php echo $this->get_field_name('totalPagesToShow'); ?>" value="<?php echo $instance['totalPagesToShow']; ?>" style="width:100%;" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('showListWithPosts'); ?>">Include blog Posts in the list:</label>
			<input id="<?php echo $this->get_field_id('showListWithPosts'); ?>" name="<?php echo $this->get_field_name('showListWithPosts'); ?>" value="1" type="checkbox"
                   <?php
                   if ($instance['showListWithPosts'] == 1) {
                       echo " Checked";
                   }
                   ?>
                   />
		</p>
<?php
        }

        // Getting the list of pages ( and posts) based on the option set by the user
        function getListOfPages($totalPagesToShow, $showListWithPosts) {
            GLOBAL $wpdb;

            if ($showListWithPosts == 1) {
                $postTypeWhere      = "post_type IN ('page', 'post')";
            } else {
                $postTypeWhere      = "post_type = 'page'";
            }
            $sql            = "SELECT ID, post_title, post_modified FROM
                                {$wpdb->posts} WHERE
                                post_status = 'publish' AND
                                {$postTypeWhere}
                                ORDER BY post_modified DESC
                                LIMIT {$totalPagesToShow}";

            $list           = (array) $wpdb->get_results($sql);

            if (!empty($list)) {
                foreach ($list as $key => $val) {
                    $val->uri = get_permalink($val->ID);
                }
            }

            return $list;
        }
    }

    // Adding the functions to the WP widget
    add_action('widgets_init', 'recently_updated_pages');
    
?>